@@ -228,6 +228,8 @@ void PiecesTable::mousePressEvent(QMouseEvent* e)
     if (e->button() == RightButton) {
         // execute RMB popup and check result
         _menu->exec(mapToGlobal(e->pos()));
+        e->accept();
+        return;
     }
     else {
         // GAME LOGIC
