@@ -18,8 +18,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -106,7 +106,7 @@ void MapLoader::load(unsigned int width, const QString &theme, unsigned int heig
   if (height == 0)
     height = width/2;
 
-  if ((image.width() != width) || (image.height() != height))
+  if ((image.width() != (int)width) || (image.height() != (int)height))
     image = image.smoothScale(width, height);
 
   // convert to light map
